# foxtail-trainer-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1
- Package version: 0.7.3
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python >=3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import foxtail_trainer_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import foxtail_trainer_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import foxtail_trainer_client
from pprint import pprint
from foxtail_trainer_client.api import custom_metric_api
from foxtail_trainer_client.model.custom_metric_dto import CustomMetricDto
# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = foxtail_trainer_client.Configuration(
    host = "http://localhost"
)



# Enter a context with an instance of the API client
with foxtail_trainer_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = custom_metric_api.CustomMetricApi(api_client)
    job_id = "jobId_example" # str | 

    try:
        api_response = api_instance.api_job_job_id_custom_metric_get_get(job_id)
        pprint(api_response)
    except foxtail_trainer_client.ApiException as e:
        print("Exception when calling CustomMetricApi->api_job_job_id_custom_metric_get_get: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CustomMetricApi* | [**api_job_job_id_custom_metric_get_get**](docs/CustomMetricApi.md#api_job_job_id_custom_metric_get_get) | **GET** /api/Job/{jobId}/CustomMetric/Get | 
*DataSetChunkApi* | [**api_prediction_task_prediction_task_id_data_set_chunk_get_all_get**](docs/DataSetChunkApi.md#api_prediction_task_prediction_task_id_data_set_chunk_get_all_get) | **GET** /api/PredictionTask/{predictionTaskId}/DataSetChunk/GetAll | Get all prediction chunks for seleceted predition task
*DataSetChunkApi* | [**api_prediction_task_prediction_task_id_data_set_chunk_get_id_get**](docs/DataSetChunkApi.md#api_prediction_task_prediction_task_id_data_set_chunk_get_id_get) | **GET** /api/PredictionTask/{predictionTaskId}/DataSetChunk/Get/{id} | 
*DataSetChunkApi* | [**api_prediction_task_prediction_task_id_data_set_chunk_submit_prediction_results_id_post**](docs/DataSetChunkApi.md#api_prediction_task_prediction_task_id_data_set_chunk_submit_prediction_results_id_post) | **POST** /api/PredictionTask/{predictionTaskId}/DataSetChunk/SubmitPredictionResults/{id} | 
*DataSetChunkApi* | [**api_prediction_task_prediction_task_id_data_set_chunk_update_prediction_status_id_put**](docs/DataSetChunkApi.md#api_prediction_task_prediction_task_id_data_set_chunk_update_prediction_status_id_put) | **PUT** /api/PredictionTask/{predictionTaskId}/DataSetChunk/UpdatePredictionStatus/{id} | 
*JobApi* | [**api_job_create_job_post**](docs/JobApi.md#api_job_create_job_post) | **POST** /api/Job/CreateJob | Create and store job entity.   Post an empty Job or Job with models
*JobApi* | [**api_job_get_all_get**](docs/JobApi.md#api_job_get_all_get) | **GET** /api/Job/GetAll | Get all jobs
*JobApi* | [**api_job_get_job_id_get**](docs/JobApi.md#api_job_get_job_id_get) | **GET** /api/Job/GetJob/{id} | Get job
*JobApi* | [**api_job_run_job_id_post**](docs/JobApi.md#api_job_run_job_id_post) | **POST** /api/Job/RunJob/{id} | Run job, start models training.
*MLModelApi* | [**api_job_job_id_ml_model_add_post**](docs/MLModelApi.md#api_job_job_id_ml_model_add_post) | **POST** /api/Job/{jobId}/MLModel/Add | Add ML models to the job
*MLModelApi* | [**api_job_job_id_ml_model_delete_all_delete**](docs/MLModelApi.md#api_job_job_id_ml_model_delete_all_delete) | **DELETE** /api/Job/{jobId}/MLModel/DeleteAll | Delete ML models from job
*MLModelApi* | [**api_job_job_id_ml_model_get_all_get**](docs/MLModelApi.md#api_job_job_id_ml_model_get_all_get) | **GET** /api/Job/{jobId}/MLModel/GetAll | Get list of model guids for job
*MLModelApi* | [**api_job_job_id_ml_model_get_id_get**](docs/MLModelApi.md#api_job_job_id_ml_model_get_id_get) | **GET** /api/Job/{jobId}/MLModel/Get/{id} | 
*MLModelApi* | [**api_job_job_id_ml_model_update_ml_models_put**](docs/MLModelApi.md#api_job_job_id_ml_model_update_ml_models_put) | **PUT** /api/Job/{jobId}/MLModel/UpdateMLModels | 
*MLModelApi* | [**api_job_job_id_ml_model_update_status_id_put**](docs/MLModelApi.md#api_job_job_id_ml_model_update_status_id_put) | **PUT** /api/Job/{jobId}/MLModel/UpdateStatus/{id} | 
*MLModelWithTrainingResultApi* | [**api_job_job_id_ml_model_with_training_result_get_id_get**](docs/MLModelWithTrainingResultApi.md#api_job_job_id_ml_model_with_training_result_get_id_get) | **GET** /api/Job/{jobId}/MLModelWithTrainingResult/Get/{id} | 
*PredictionTaskApi* | [**api_prediction_task_create_post**](docs/PredictionTaskApi.md#api_prediction_task_create_post) | **POST** /api/PredictionTask/Create | Create prediction task
*PredictionTaskApi* | [**api_prediction_task_get_id_get**](docs/PredictionTaskApi.md#api_prediction_task_get_id_get) | **GET** /api/PredictionTask/Get/{id} | 
*PredictionTaskApi* | [**api_prediction_task_run_prediction_id_post**](docs/PredictionTaskApi.md#api_prediction_task_run_prediction_id_post) | **POST** /api/PredictionTask/RunPrediction/{id} | Run prediction
*ReportApi* | [**api_job_job_id_report_get_job_metric_get**](docs/ReportApi.md#api_job_job_id_report_get_job_metric_get) | **GET** /api/Job/{jobId}/Report/GetJobMetric | 
*ReportApi* | [**api_job_job_id_report_get_ml_models_metric_get**](docs/ReportApi.md#api_job_job_id_report_get_ml_models_metric_get) | **GET** /api/Job/{jobId}/Report/GetMLModelsMetric | 
*ReportApi* | [**api_job_job_id_report_get_ml_models_status_counts_get**](docs/ReportApi.md#api_job_job_id_report_get_ml_models_status_counts_get) | **GET** /api/Job/{jobId}/Report/GetMLModelsStatusCounts | 
*ReportApi* | [**api_job_job_id_report_get_ml_models_status_get**](docs/ReportApi.md#api_job_job_id_report_get_ml_models_status_get) | **GET** /api/Job/{jobId}/Report/GetMLModelsStatus | Get status for every model. Report contains model id and current status.
*ReportApi* | [**api_job_job_id_report_get_ml_models_url_get**](docs/ReportApi.md#api_job_job_id_report_get_ml_models_url_get) | **GET** /api/Job/{jobId}/Report/GetMLModelsUrl | 
*ReportApi* | [**api_job_job_id_report_get_training_time_get**](docs/ReportApi.md#api_job_job_id_report_get_training_time_get) | **GET** /api/Job/{jobId}/Report/GetTrainingTime | 
*TrainingConfigApi* | [**api_job_job_id_training_config_get_id_get**](docs/TrainingConfigApi.md#api_job_job_id_training_config_get_id_get) | **GET** /api/Job/{jobId}/TrainingConfig/Get/{id} | 
*TrainingConfigApi* | [**api_job_job_id_training_config_update_put**](docs/TrainingConfigApi.md#api_job_job_id_training_config_update_put) | **PUT** /api/Job/{jobId}/TrainingConfig/Update | 
*TrainingResultApi* | [**api_job_job_id_ml_model_ml_model_id_training_result_create_post**](docs/TrainingResultApi.md#api_job_job_id_ml_model_ml_model_id_training_result_create_post) | **POST** /api/Job/{jobId}/MLModel/{mlModelId}/TrainingResult/Create | 
*TrainingResultApi* | [**api_job_job_id_ml_model_ml_model_id_training_result_get_id_get**](docs/TrainingResultApi.md#api_job_job_id_ml_model_ml_model_id_training_result_get_id_get) | **GET** /api/Job/{jobId}/MLModel/{mlModelId}/TrainingResult/Get/{id} | 
*WorkerApi* | [**api_job_job_id_worker_get**](docs/WorkerApi.md#api_job_job_id_worker_get) | **GET** /api/Job/{jobId}/Worker | 
*WorkerApi* | [**api_job_job_id_worker_worker_id_get**](docs/WorkerApi.md#api_job_job_id_worker_worker_id_get) | **GET** /api/Job/{jobId}/Worker/{workerId} | 


## Documentation For Models

 - [AddOrUpdateModelHyperparameter](docs/AddOrUpdateModelHyperparameter.md)
 - [AddOrUpdateModelHyperparameterInJob](docs/AddOrUpdateModelHyperparameterInJob.md)
 - [AggregatedMetricReportDto](docs/AggregatedMetricReportDto.md)
 - [CreateCustomMetricDto](docs/CreateCustomMetricDto.md)
 - [CreateDataSetsSizesDto](docs/CreateDataSetsSizesDto.md)
 - [CreateJobCommand](docs/CreateJobCommand.md)
 - [CreateMLModelDto](docs/CreateMLModelDto.md)
 - [CreateMLModelsCommand](docs/CreateMLModelsCommand.md)
 - [CreateMetricDto](docs/CreateMetricDto.md)
 - [CreateModelHyperparameterDto](docs/CreateModelHyperparameterDto.md)
 - [CreatePredictionTaskCommand](docs/CreatePredictionTaskCommand.md)
 - [CreateTrainingConfigDto](docs/CreateTrainingConfigDto.md)
 - [CreateTrainingHistoryDto](docs/CreateTrainingHistoryDto.md)
 - [CreateTrainingResultCommand](docs/CreateTrainingResultCommand.md)
 - [CreateTrainingResultDto](docs/CreateTrainingResultDto.md)
 - [CreatedJobDto](docs/CreatedJobDto.md)
 - [CreatedMLModelsDto](docs/CreatedMLModelsDto.md)
 - [CreatedPredictionTaskDto](docs/CreatedPredictionTaskDto.md)
 - [CustomMetricDto](docs/CustomMetricDto.md)
 - [CustomModelHyperparameterDto](docs/CustomModelHyperparameterDto.md)
 - [CustomModelHyperparameterWithModelDto](docs/CustomModelHyperparameterWithModelDto.md)
 - [DataSetChunkBasicDto](docs/DataSetChunkBasicDto.md)
 - [DataSetChunkDto](docs/DataSetChunkDto.md)
 - [DataSetChunksListDto](docs/DataSetChunksListDto.md)
 - [DataSetsSizesDto](docs/DataSetsSizesDto.md)
 - [DeletedMLModelsDto](docs/DeletedMLModelsDto.md)
 - [GetWorkerDto](docs/GetWorkerDto.md)
 - [JobBasicDto](docs/JobBasicDto.md)
 - [JobDto](docs/JobDto.md)
 - [JobMetricReportDto](docs/JobMetricReportDto.md)
 - [JobTrainingConfigDto](docs/JobTrainingConfigDto.md)
 - [JobsListDto](docs/JobsListDto.md)
 - [LogDto](docs/LogDto.md)
 - [LogLevel](docs/LogLevel.md)
 - [MLModelDto](docs/MLModelDto.md)
 - [MLModelMetricReportDto](docs/MLModelMetricReportDto.md)
 - [MLModelsGuidsListDto](docs/MLModelsGuidsListDto.md)
 - [MLModelsMetricListReportDto](docs/MLModelsMetricListReportDto.md)
 - [MLModelsStatusCountReportDto](docs/MLModelsStatusCountReportDto.md)
 - [MLModelsStatusCountsListReportDto](docs/MLModelsStatusCountsListReportDto.md)
 - [MLModelsStatusListReportDto](docs/MLModelsStatusListReportDto.md)
 - [MLModelsStatusReportDto](docs/MLModelsStatusReportDto.md)
 - [MLModelsUrlListReportDto](docs/MLModelsUrlListReportDto.md)
 - [MLModelsUrlReportDto](docs/MLModelsUrlReportDto.md)
 - [MLModelsWithTrainingResultsDto](docs/MLModelsWithTrainingResultsDto.md)
 - [MetricDto](docs/MetricDto.md)
 - [MetricDtoWithModel](docs/MetricDtoWithModel.md)
 - [MetricReportDto](docs/MetricReportDto.md)
 - [MetricType](docs/MetricType.md)
 - [ModelHyperparameterDto](docs/ModelHyperparameterDto.md)
 - [ModelStatus](docs/ModelStatus.md)
 - [ModelType](docs/ModelType.md)
 - [OverrideModelHyperparameterCommand](docs/OverrideModelHyperparameterCommand.md)
 - [PredictionInputModelDto](docs/PredictionInputModelDto.md)
 - [PredictionModelTaskDto](docs/PredictionModelTaskDto.md)
 - [PredictionStatus](docs/PredictionStatus.md)
 - [PredictionTaskDto](docs/PredictionTaskDto.md)
 - [ProblemType](docs/ProblemType.md)
 - [RunJobCommand](docs/RunJobCommand.md)
 - [RunPredictionTaskCommand](docs/RunPredictionTaskCommand.md)
 - [RunedJobDto](docs/RunedJobDto.md)
 - [RunedPredictionTaskDto](docs/RunedPredictionTaskDto.md)
 - [SubmitPredictionCommand](docs/SubmitPredictionCommand.md)
 - [TrainingConfigDto](docs/TrainingConfigDto.md)
 - [TrainingHistoryDto](docs/TrainingHistoryDto.md)
 - [TrainingResultDto](docs/TrainingResultDto.md)
 - [TrainingResultWithModelDto](docs/TrainingResultWithModelDto.md)
 - [TrainingTimeReportDto](docs/TrainingTimeReportDto.md)
 - [UpdateDataSetChunkStatusCommand](docs/UpdateDataSetChunkStatusCommand.md)
 - [UpdateDataSetsSizesDto](docs/UpdateDataSetsSizesDto.md)
 - [UpdateJobTrainingConfigCommand](docs/UpdateJobTrainingConfigCommand.md)
 - [UpdateMLModelDefinitionDto](docs/UpdateMLModelDefinitionDto.md)
 - [UpdateMLModelsDefinitionCommand](docs/UpdateMLModelsDefinitionCommand.md)
 - [UpdateMLModelsStatusCommand](docs/UpdateMLModelsStatusCommand.md)
 - [WorkerMLModelDto](docs/WorkerMLModelDto.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author




## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in foxtail_trainer_client.apis and foxtail_trainer_client.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from foxtail_trainer_client.api.default_api import DefaultApi`
- `from foxtail_trainer_client.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import foxtail_trainer_client
from foxtail_trainer_client.apis import *
from foxtail_trainer_client.models import *
```

